@@ -232,8 +232,8 @@ class ArgumentParser(argparse.ArgumentParser):
             else:
                 namespace.saver = None
 
-    def parse_args(self, args=None):
-        options = argparse.ArgumentParser.parse_args(self, args)
+    def parse_args(self, args=None, namespace=None):
+        options = argparse.ArgumentParser.parse_args(self, args, namespace)
         try:
             options.pages = utils.parse_page_numbers(options.pages)
         except (TypeError, ValueError):
@@ -306,8 +306,6 @@ class Context(djvu.decode.Context):
 
     @contextlib.contextmanager
     def get_output_image(self, nth, page_job):
-        size = page_job.size
-        rect = (0, 0) + size
         output_format = self._image_format
         file = self._temp_file('%06d.%s' % (nth, output_format.extension))
         try:
