@@ -25,11 +25,6 @@ class EngineNotFound(Exception):
     def __init__(self, name):
         Exception.__init__(self, 'OCR engine (%s) was not found' % name)
 
-class SecurityConcern(Exception):
-
-    def __init__(self):
-        Exception.__init__(self, 'I refuse to process this file due to security concerns')
-
 class MalformedOcrOutput(Exception):
 
     def __init__(self, message):
