@@ -148,7 +148,7 @@ def _apply_bboxes(djvu_class, title, text, settings):
             text_zones.Zone(type=const.TEXT_ZONE_CHARACTER, bbox=(x0, y0, x1, y1), children=[ch])
             for (x0, y0, x1, y1), ch in zip(coordinates, text)
         ]
-    return text,
+    return [text]
 
 def _scan(node, settings):
 
@@ -188,7 +188,10 @@ def _scan(node, settings):
     if m is None:
         bbox = text_zones.BBox()
     else:
-        bbox = text_zones.BBox(*(int(m.group(id)) for id in ('x0', 'y0', 'x1', 'y1')))
+        bbox = text_zones.BBox(
+            *(int(m.group(ident))
+            for ident in ('x0', 'y0', 'x1', 'y1'))
+        )
 
     if djvu_class is const.TEXT_ZONE_PAGE:
         if not bbox:
