@@ -22,10 +22,8 @@ from subprocess import CalledProcessError
 # Protect from scanadf[0] and possibly other brain-dead software that set
 # SIGCHLD to SIG_IGN.
 # [0] http://bugs.debian.org/596232
-try:
+if os.name == 'posix':
     signal.signal(signal.SIGCHLD, signal.SIG_DFL)
-except AttributeError:
-    pass
 
 def get_signal_names():
     _signame_pattern = re.compile('^SIG[A-Z0-9]*$')
